(tutorials)=

# Tutorials

Here we provide a series of tutorials to help you get started with aiida-vasp.
There are several ways to use aiida-vasp. Here we start with the easiest interface - using
the `BuilderUpdater` class that allows you to create workflows using pre-define, customizable  templates for both calculations parameters and settings for code execution.

```{toctree}
:maxdepth: 1

./silicon_sp.md
./silicon_relax.md
./silicon_band_dos.md
```
